pub struct FetchResponse {
pub status: u16,
pub headers: HashMap<String, String>,
pub body: String,
}Expand description
Successful response from fetch.
Fields
status: u16HTTP status code returned by the upstream.
headers: HashMap<String, String>Response headers (lowercased keys, as the host normalises them).
body: StringResponse body as a UTF-8 string. Binary upstream responses are returned as the lossy UTF-8 conversion of their bytes - fetch a JSON or text endpoint, or have the upstream base64-encode binary data.