CryptoError

Enum CryptoError 

pub enum CryptoError {
    NoResult,
    BadBase64,
}
Errors returned by the higher-level crypto wrappers.

Variants



NoResult

The host returned no result. Usually means the secret is not in the flare’s allowlist, the secret name does not exist, the algorithm is not supported, or the input was invalid.



BadBase64

The ciphertext passed to decrypt_aes was not valid base64.